@@ -1,23 +1,24 @@
 use std::path::Path;
+use liz::LizError;
 
-fn main() {
+fn main() -> Result<(), LizError> {
     let mut to_execute: Vec<Box<dyn AsRef<Path>>> = Vec::new();
     let mut to_execute_args: Option<Vec<String>> = None;
-    let mut start_execute_args = false;
+    let mut getting_args = false;
     for arg in std::env::args() {
-        if !start_execute_args {
+        if !getting_args {
             if arg == "--" {
-                start_execute_args = true;
+                getting_args = true;
             } else if arg.ends_with(".liz") || arg.ends_with(".lua") {
                 to_execute.push(Box::new(arg));
             } else if arg == "-v" || arg == "--version" {
                 let version = env!("CARGO_PKG_VERSION");
                 println!("Liz (LuaWizard) {}", version);
-                return;
+                return Ok(());
             }
         } else {
-            if let Some(ref mut liz_args) = to_execute_args {
-                liz_args.push(arg);
+            if let Some(ref mut to_execute_args) = to_execute_args {
+                to_execute_args.push(arg);
             } else {
                 to_execute_args = Some(vec![arg]);
             }
@@ -29,14 +30,11 @@ fn main() {
             to_execute.push(Box::new(default));
         }
     }
-    for path in to_execute {
-        execute(path.as_ref(), to_execute_args.clone());
+    if !to_execute.is_empty() {
+        let handler = liz::start(to_execute_args)?;
+        for path in to_execute {
+            liz::load(path.as_ref(), &handler)?;
+        }
     }
-}
-
-fn execute(path: impl AsRef<Path>, args: Option<Vec<String>>) {
-    match liz::execute(path, args) {
-        Ok(result) => println!("{}", result),
-        Err(error) => eprintln!("{}", error),
-    };
+    Ok(())
 }
